@@ -1,4 +1,5 @@
 import abc
+import builtins
 import datetime
 import enum
 import typing
@@ -7,12 +8,14 @@ import jsii
 import jsii.compat
 import publication
 
-from jsii.python import classproperty
-
 import aws_cdk.aws_autoscaling
+import aws_cdk.aws_cloudformation
 import aws_cdk.aws_ec2
 import aws_cdk.aws_iam
-import aws_cdk.cdk
+import aws_cdk.aws_lambda
+import aws_cdk.aws_ssm
+import aws_cdk.core
+import aws_cdk.custom_resources
 __all__ = []
 
 publication.publish()
